/***************************************************************************                        
 *   Copyright (C) 2008 by Jaroslav Reznik <jreznik@redhat.com>            *                        
 *                                                                         *                        
 *   This program is free software; you can redistribute it and/or modify  *                        
 *   it under the terms of the GNU General Public License as published by  *                        
 *   the Free Software Foundation; either version 2 of the License, or     *                        
 *   (at your option) any later version.                                   *                        
 *                                                                         *                        
 *   This program is distributed in the hope that it will be useful,       *                        
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *                        
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *                        
 *   GNU General Public License for more details.                          *                        
 *                                                                         *                        
 *   You should have received a copy of the GNU General Public License     *                        
 *   along with this program; if not, write to the                         *                        
 *   Free Software Foundation, Inc.,                                       *                        
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *                        
 ***************************************************************************/ 

#include "networkstatusengine.h"

//solid specific includes
#include <solid/networking.h>

#include <kdebug.h>
#include <klocale.h>

#include "plasma/datacontainer.h"

NetworkstatusEngine::NetworkstatusEngine(QObject* parent, const QVariantList& args)
        : Plasma::DataEngine(parent, args)
        , m_notifier(0)
        , m_sources(0)
{
    Q_UNUSED(args)
    
    setMinimumPollingInterval(333);
        
    m_sources << I18N_NOOP("NetworkStatus");
}

NetworkstatusEngine::~NetworkstatusEngine()
{}

void NetworkstatusEngine::init()
{
}

QStringList NetworkstatusEngine::sources() const 
{
    return m_sources;
}

bool NetworkstatusEngine::sourceRequestEvent(const QString &name)
{
    updateSourceEvent(name);
}

bool NetworkstatusEngine::updateSourceEvent(const QString &name)
{
    QString status;

    if (name == I18N_NOOP("NetworkStatus")) {
	switch(Solid::Networking::status()) {
	case Solid::Networking::Unknown:
	    status = I18N_NOOP("unknown");
	    break;
	case Solid::Networking::Unconnected:
	    status = I18N_NOOP("unconnected");
	    break;
	case Solid::Networking::Disconnecting:
	    status = I18N_NOOP("disconnecting");
	    break;
	case Solid::Networking::Connecting:
	    status = I18N_NOOP("connecting");
	    break;
	case Solid::Networking::Connected:
	    status = I18N_NOOP("connected");
	    break;
	}

        setData(I18N_NOOP("NetworkStatus"), I18N_NOOP("status"), status);
        return true;
    } else {
        kDebug() << "Data for '" << name << "' not found";
    }
    return true;
}

#include "networkstatusengine.moc"
